@@ -1407,3 +1407,119 @@ class NetworkElementUpdate:
     def data(self, value):
         if value is not None:
             self.pb.data.CopyFrom(value.pb)
+
+
+class NetworkElementDiscovery:
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        self.pb = pb if pb else network_poller_pb2.NetworkElementDiscovery()
+        self.errctx = errctx
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+        self.errors = Repeated(None, self.pb.errors, self.errctx)
+
+    @property
+    def time(self):
+        return self.pb.time.seconds
+    @time.setter
+    def time(self, value):  # assumes seconds
+        if value is not None:
+            self.pb.time.FromSeconds(int(value))
+
+    @property
+    def company_uuid(self):
+        return self.pb.company_uuid
+    @company_uuid.setter
+    def company_uuid(self, value):
+        if value is not None:
+            self.pb.company_uuid = value
+
+    @property
+    def element_discovery_uuid(self):
+        return self.pb.element_discovery_uuid
+    @element_discovery_uuid.setter
+    def element_discovery_uuid(self, value):
+        if value is not None:
+            self.pb.element_discovery_uuid = value
+
+    @property
+    def instance(self):
+        return self.pb.instance
+    @instance.setter
+    def instance(self, value):
+        if value is not None:
+            self.pb.instance = value
+
+    @property
+    def active(self):
+        return self.pb.active
+    @active.setter
+    def active(self, value):
+        if value is not None:
+            self.pb.active = value
+
+    @property
+    def pingable(self):
+        return self.pb.pingable
+    @pingable.setter
+    def pingable(self, value):
+        if value is not None:
+            self.pb.pingable = value
+
+    @property
+    def ping_time(self):
+        return self.pb.ping_time if self.pb.HasField('ping_time') else None
+    @ping_time.setter
+    def ping_time(self, value):
+        if value is None:
+            self.pb.ClearField('ping_time')
+        else:
+            if value >= 0 and int.bit_length(value) < 32:
+                self.pb.ping_time = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.Error.ERROR_BAD_DATA_RANGE,
+                        'Invalid value for NetworkElementDiscovery.ping_time',
+                        value=value, metric_name='NetworkElementDiscovery.ping_time')
+
+    @property
+    def snmp_version(self):
+        return self.pb.snmp_version
+    @snmp_version.setter
+    def snmp_version(self, value):
+        if value is not None:
+            self.pb.snmp_version = value
+
+    @property
+    def sysobjid(self):
+        return self.pb.sysobjid if self.pb.HasField('sysobjid') else None
+    @sysobjid.setter
+    def sysobjid(self, value):
+        if value is None:
+            self.pb.ClearField('sysobjid')
+        else:
+            self.pb.sysobjid = value
+
+    @property
+    def poller_version(self):
+        return self.pb.poller_version
+    @poller_version.setter
+    def poller_version(self, value):
+        if value is None:
+            self.pb.ClearField('poller_version')
+        else:
+            self.pb.poller_version = value
+
+    @property
+    def poller_hash(self):
+        return self.pb.poller_hash
+    @poller_hash.setter
+    def poller_hash(self, value):
+        if value is not None:
+            self.pb.poller_hash = value
+
+    @property
+    def status(self):
+        return self.pb.status
+    @status.setter
+    def status(self, value):
+        if value is not None:
+            self.pb.status = value
\ No newline at end of file
