@@ -42,6 +42,7 @@ def _py_result(model, r, del_uuid):
             fields[f] = v
         uuid = fields.get('uuid')
         if uuid:
+            # handle this as a managed object
             cur = model._objs.get(uuid)
             if cur:
                 curpb, curpy = cur
@@ -65,7 +66,8 @@ def _py_result(model, r, del_uuid):
                 curpy = cls(**fields)
                 model._objs[uuid] = (pb, curpy)
             return curpy
-        raise RuntimeError('No UUID found on received object')
+        # no uuid, just return the object unmanagd.
+        return cls(**fields)
 
     if isinstance(r, list):
         if r:
